# Junior SSL (Omniwheel soccer setup)

![Robots](/docs/imgs/cover.jpg)

## Presentation

[YouTube demonstration video](https://www.youtube.com/watch?v=4NFXbaom7YQ)

The goal of this project is to provide an open-source material to build and operate a setup featuring
omniwheel robots and a soccer field monitoring them with a camera.

With this setup, it is possible for two teams to code a program and play against each other.

## Documentation

**This is a WORK IN PROGRESS, you can't (yet) build the whole setup by following instructions from
this repository, if any question, do not hesitate to open an issue**

* [Robots](/docs/robots.md)
* [Coordinates, field and markers](/docs/coordinates-markers.md)
* [Game Controller and Python API](/docs/programming.md)

## License

<a rel="license" href="http://creativecommons.org/licenses/by-nc/2.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-nc/2.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-nc/2.0/">Creative Commons Attribution-NonCommercial 2.0 Generic License</a>.